@@ -18,24 +18,22 @@ package controllers
 
 import (
 	"context"
+	"fmt"
 	"reflect"
 	"time"
 
 	performancev2 "github.com/openshift-kni/performance-addon-operators/api/v2"
 	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/kubeletconfig"
 	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/machineconfig"
+	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/manifestset"
 	profileutil "github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/profile"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/runtimeclass"
-	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components/tuned"
-	v1 "github.com/openshift/api/config/v1"
 	tunedv1 "github.com/openshift/cluster-node-tuning-operator/pkg/apis/tuned/v1"
 	mcov1 "github.com/openshift/machine-config-operator/pkg/apis/machineconfiguration.openshift.io/v1"
 
 	corev1 "k8s.io/api/core/v1"
 	nodev1beta1 "k8s.io/api/node/v1beta1"
 	apiequality "k8s.io/apimachinery/pkg/api/equality"
-	"k8s.io/apimachinery/pkg/api/errors"
+	k8serros "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -75,8 +73,8 @@ func (r *PerformanceProfileReconciler) SetupWithManager(mgr ctrl.Manager) error
 				return false
 			}
 
-			return e.MetaNew.GetGeneration() != e.MetaOld.GetGeneration() ||
-				!apiequality.Semantic.DeepEqual(e.MetaNew.GetLabels(), e.MetaOld.GetLabels())
+			return e.ObjectNew.GetGeneration() != e.ObjectOld.GetGeneration() ||
+				!apiequality.Semantic.DeepEqual(e.ObjectNew.GetLabels(), e.ObjectOld.GetLabels())
 		},
 	}
 
@@ -114,12 +112,8 @@ func (r *PerformanceProfileReconciler) SetupWithManager(mgr ctrl.Manager) error
 		Owns(&nodev1beta1.RuntimeClass{}, builder.WithPredicates(p)).
 		Watches(
 			&source.Kind{Type: &mcov1.MachineConfigPool{}},
-			&handler.EnqueueRequestsFromMapFunc{ToRequests: handler.ToRequestsFunc(r.mcpToPerformanceProfile)},
+			handler.EnqueueRequestsFromMapFunc(r.mcpToPerformanceProfile),
 			builder.WithPredicates(mcpPredicates)).
-		Watches(
-			&source.Kind{Type: &v1.ClusterVersion{}},
-			&handler.EnqueueRequestsFromMapFunc{ToRequests: handler.ToRequestsFunc(r.requestAllPerformanceProfiles)},
-			builder.WithPredicates(p)).
 		Complete(r)
 	if err != nil {
 		return err
@@ -127,12 +121,12 @@ func (r *PerformanceProfileReconciler) SetupWithManager(mgr ctrl.Manager) error
 	return nil
 }
 
-func (r *PerformanceProfileReconciler) mcpToPerformanceProfile(mcpObj handler.MapObject) []reconcile.Request {
+func (r *PerformanceProfileReconciler) mcpToPerformanceProfile(mcpObj client.Object) []reconcile.Request {
 	mcp := &mcov1.MachineConfigPool{}
 
 	key := types.NamespacedName{
-		Namespace: mcpObj.Meta.GetNamespace(),
-		Name:      mcpObj.Meta.GetName(),
+		Namespace: mcpObj.GetNamespace(),
+		Name:      mcpObj.GetName(),
 	}
 	if err := r.Get(context.TODO(), key, mcp); err != nil {
 		klog.Errorf("failed to get the machine config pool %+v", key)
@@ -147,14 +141,14 @@ func (r *PerformanceProfileReconciler) mcpToPerformanceProfile(mcpObj handler.Ma
 
 	var requests []reconcile.Request
 	for i, profile := range profiles.Items {
-		machineConfigPoolSelector := labels.Set(profileutil.GetMachineConfigPoolSelector(&profile))
-		selector, err := metav1.LabelSelectorAsSelector(mcp.Spec.MachineConfigSelector)
+		profileNodeSelector := labels.Set(profile.Spec.NodeSelector)
+		mcpNodeSelector, err := metav1.LabelSelectorAsSelector(mcp.Spec.NodeSelector)
 		if err != nil {
-			klog.Errorf("failed to parse the selector %v", mcp.Spec.MachineConfigSelector)
+			klog.Errorf("failed to parse the selector %v", mcp.Spec.NodeSelector)
 			return nil
 		}
 
-		if selector.Matches(machineConfigPoolSelector) {
+		if mcpNodeSelector.Matches(profileNodeSelector) {
 			requests = append(requests, reconcile.Request{NamespacedName: namespacedName(&profiles.Items[i])})
 		}
 	}
@@ -162,28 +156,7 @@ func (r *PerformanceProfileReconciler) mcpToPerformanceProfile(mcpObj handler.Ma
 	return requests
 }
 
-func (r *PerformanceProfileReconciler) requestAllPerformanceProfiles(mcpObj handler.MapObject) []reconcile.Request {
-	profiles := &performancev2.PerformanceProfileList{}
-	if err := r.List(context.TODO(), profiles); err != nil {
-		klog.Error("failed to get performance profiles")
-		return nil
-	}
-	var requests []reconcile.Request
-	for i := range profiles.Items {
-		requests = append(requests, reconcile.Request{NamespacedName: namespacedName(&profiles.Items[i])})
-	}
-	return requests
-}
-
 func validateUpdateEvent(e *event.UpdateEvent) bool {
-	if e.MetaOld == nil {
-		klog.Error("Update event has no old metadata")
-		return false
-	}
-	if e.MetaNew == nil {
-		klog.Error("Update event has no new metadata")
-		return false
-	}
 	if e.ObjectOld == nil {
 		klog.Error("Update event has no old runtime object to update")
 		return false
@@ -197,13 +170,13 @@ func validateUpdateEvent(e *event.UpdateEvent) bool {
 }
 
 // +kubebuilder:rbac:groups="",resources=events,verbs=*
+// +kubebuilder:rbac:groups="",resources=nodes,verbs=get;list;watch
 // +kubebuilder:rbac:groups=performance.openshift.io,resources=performanceprofiles;performanceprofiles/status;performanceprofiles/finalizers,verbs=*
 // +kubebuilder:rbac:groups=machineconfiguration.openshift.io,resources=machineconfigs;machineconfigpools;kubeletconfigs,verbs=*
-// +kubebuilder:rbac:groups=config.openshift.io,resources=clusterversions,verbs=get;list;watch
-// +kubebuilder:rbac:groups=tuned.openshift.io,resources=tuneds,verbs=*
+// +kubebuilder:rbac:groups=tuned.openshift.io,resources=tuneds;profiles,verbs=*
 // +kubebuilder:rbac:groups=node.k8s.io,resources=runtimeclasses,verbs=*
 // +kubebuilder:rbac:namespace="openshift-performance-addon-operator",groups=core,resources=pods;services;services/finalizers;configmaps,verbs=*
-// +kubebuilder:rbac:namespace="openshift-performance-addon-operator",groups=apps,resources=deployments;daemonsets;replicasets;statefulsets,verbs=*
+// +kubebuilder:rbac:namespace="openshift-performance-addon-operator",groups=coordination.k8s.io,resources=leases,verbs=create;get;list;update
 // +kubebuilder:rbac:namespace="openshift-performance-addon-operator",groups=apps,resourceNames=performance-operator,resources=deployments/finalizers,verbs=update
 // +kubebuilder:rbac:namespace="openshift-performance-addon-operator",groups=monitoring.coreos.com,resources=servicemonitors,verbs=*
 
@@ -212,14 +185,14 @@ func validateUpdateEvent(e *event.UpdateEvent) bool {
 // Note:
 // The Controller will requeue the Request to be processed again if the returned error is non-nil or
 // Result.Requeue is true, otherwise upon completion it will remove the work from the queue.
-func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error) {
+func (r *PerformanceProfileReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error) {
 	klog.Info("Reconciling PerformanceProfile")
 
 	// Fetch the PerformanceProfile instance
 	instance := &performancev2.PerformanceProfile{}
-	err := r.Get(context.TODO(), req.NamespacedName, instance)
+	err := r.Get(ctx, req.NamespacedName, instance)
 	if err != nil {
-		if errors.IsNotFound(err) {
+		if k8serros.IsNotFound(err) {
 			// Request object not found, could have been deleted after reconcile request.
 			// Owned objects are automatically garbage collected. For additional cleanup logic use finalizers.
 			// Return and don't requeue
@@ -245,7 +218,7 @@ func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result,
 		// remove finalizer
 		if hasFinalizer(instance, finalizer) {
 			removeFinalizer(instance, finalizer)
-			if err := r.Update(context.TODO(), instance); err != nil {
+			if err := r.Update(ctx, instance); err != nil {
 				return reconcile.Result{}, err
 			}
 
@@ -257,7 +230,7 @@ func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result,
 	if !hasFinalizer(instance, finalizer) {
 		instance.Finalizers = append(instance.Finalizers, finalizer)
 		instance.Status.Conditions = r.getProgressingConditions("DeploymentStarting", "Deployment is starting")
-		if err := r.Update(context.TODO(), instance); err != nil {
+		if err := r.Update(ctx, instance); err != nil {
 			return reconcile.Result{}, err
 		}
 
@@ -265,23 +238,34 @@ func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result,
 		return reconcile.Result{}, nil
 	}
 
-	// TODO: we need to check if all under performance profiles values != nil
-	// first we need to decide if each of values required and we should move the check into validation webhook
-	// for now let's assume that all parameters needed for assets scrips are required
-	if err := profileutil.ValidateParameters(instance); err != nil {
-		klog.Errorf("failed to reconcile: %v", err)
-		r.Recorder.Eventf(instance, corev1.EventTypeWarning, "Validation failed", "Profile validation failed: %v", err)
-		conditions := r.getDegradedConditions(conditionReasonValidationFailed, err.Error())
+	profileMCP, err := r.getMachineConfigPoolByProfile(instance)
+	if err != nil {
+		conditions := r.getDegradedConditions(conditionFailedToFindMachineConfigPool, err.Error())
 		if err := r.updateStatus(instance, conditions); err != nil {
 			klog.Errorf("failed to update performance profile %q status: %v", instance.Name, err)
 			return reconcile.Result{}, err
 		}
-		// we do not want to reconcile again in case of error, because a user will need to update the PerformanceProfile anyway
+
 		return reconcile.Result{}, nil
 	}
 
+	if err := validateProfileMachineConfigPool(instance, profileMCP); err != nil {
+		conditions := r.getDegradedConditions(conditionBadMachineConfigLabels, err.Error())
+		if err := r.updateStatus(instance, conditions); err != nil {
+			klog.Errorf("failed to update performance profile %q status: %v", instance.Name, err)
+			return reconcile.Result{}, err
+		}
+
+		return reconcile.Result{}, nil
+	}
+
+	// remove components with the old name after the upgrade
+	if err := r.deleteDeprecatedComponents(instance); err != nil {
+		return ctrl.Result{}, err
+	}
+
 	// apply components
-	result, err := r.applyComponents(instance)
+	result, err := r.applyComponents(instance, profileMCP)
 	if err != nil {
 		klog.Errorf("failed to deploy performance profile %q components: %v", instance.Name, err)
 		r.Recorder.Eventf(instance, corev1.EventTypeWarning, "Creation failed", "Failed to create all components: %v", err)
@@ -301,12 +285,20 @@ func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result,
 
 	// get MCP degraded conditions
 	if conditions == nil {
-		conditions, err = r.getMCPConditionsByProfile(instance)
+		conditions, err = r.getMCPDegradedCondition(profileMCP)
 		if err != nil {
 			return r.updateDegradedCondition(instance, conditionFailedGettingMCPStatus, err)
 		}
 	}
 
+	// get tuned profile degraded conditions
+	if conditions == nil {
+		conditions, err = r.getTunedConditionsByProfile(instance)
+		if err != nil {
+			return r.updateDegradedCondition(instance, conditionFailedGettingTunedProfileStatus, err)
+		}
+	}
+
 	// if conditions were not added due to machine config pool status change then set as available
 	if conditions == nil {
 		conditions = r.getAvailableConditions()
@@ -329,6 +321,12 @@ func (r *PerformanceProfileReconciler) Reconcile(req ctrl.Request) (ctrl.Result,
 	return ctrl.Result{}, nil
 }
 
+func (r *PerformanceProfileReconciler) deleteDeprecatedComponents(instance *performancev2.PerformanceProfile) error {
+	// remove the machine config with the deprecated name
+	name := components.GetComponentName(instance.Name, components.ComponentNamePrefix)
+	return r.deleteMachineConfig(name)
+}
+
 func (r *PerformanceProfileReconciler) updateDegradedCondition(instance *performancev2.PerformanceProfile, conditionState string, conditionError error) (ctrl.Result, error) {
 	conditions := r.getDegradedConditions(conditionState, conditionError.Error())
 	if err := r.updateStatus(instance, conditions); err != nil {
@@ -338,93 +336,42 @@ func (r *PerformanceProfileReconciler) updateDegradedCondition(instance *perform
 	return reconcile.Result{}, conditionError
 }
 
-func (r *PerformanceProfileReconciler) ppRequestsFromMCP(o handler.MapObject) []reconcile.Request {
-	mcp := &mcov1.MachineConfigPool{}
-
-	if err := r.Get(context.TODO(),
-		types.NamespacedName{
-			Namespace: o.Meta.GetNamespace(),
-			Name:      o.Meta.GetName(),
-		},
-		mcp,
-	); err != nil {
-		klog.Errorf("Unable to retrieve mcp %q from store: %v", namespacedName(o.Meta).String(), err)
-		return nil
-	}
-
-	ppList := &performancev2.PerformanceProfileList{}
-	if err := r.List(context.TODO(), ppList); err != nil {
-		klog.Errorf("Unable to list performance profiles: %v", err)
-		return nil
-	}
-
-	var requests []reconcile.Request
-	for k := range ppList.Items {
-		if hasMatchingLabels(&ppList.Items[k], mcp) {
-			requests = append(requests, reconcile.Request{NamespacedName: namespacedName(&ppList.Items[k])})
-		}
-	}
-
-	return requests
-}
-
-func (r *PerformanceProfileReconciler) applyComponents(profile *performancev2.PerformanceProfile) (*reconcile.Result, error) {
-
+func (r *PerformanceProfileReconciler) applyComponents(profile *performancev2.PerformanceProfile, profileMCP *mcov1.MachineConfigPool) (*reconcile.Result, error) {
 	if profileutil.IsPaused(profile) {
 		klog.Infof("Ignoring reconcile loop for pause performance profile %s", profile.Name)
 		return nil, nil
 	}
 
-	// get mutated machine config
-	mc, err := machineconfig.New(r.AssetsDir, profile)
+	components, err := manifestset.GetNewComponents(profile, profileMCP, &r.AssetsDir)
 	if err != nil {
 		return nil, err
 	}
-	if err := controllerutil.SetControllerReference(profile, mc, r.Scheme); err != nil {
-		return nil, err
+	for _, componentObj := range components.ToObjects() {
+		if err := controllerutil.SetControllerReference(profile, componentObj, r.Scheme); err != nil {
+			return nil, err
+		}
 	}
-	mcMutated, err := r.getMutatedMachineConfig(mc)
+
+	// get mutated machine config
+	mcMutated, err := r.getMutatedMachineConfig(components.MachineConfig)
 	if err != nil {
 		return nil, err
 	}
 
 	// get mutated kubelet config
-	kc, err := kubeletconfig.New(profile)
-	if err != nil {
-		return nil, err
-	}
-	if err := controllerutil.SetControllerReference(profile, kc, r.Scheme); err != nil {
-		return nil, err
-	}
-	kcMutated, err := r.getMutatedKubeletConfig(kc)
+	kcMutated, err := r.getMutatedKubeletConfig(components.KubeletConfig)
 	if err != nil {
 		return nil, err
 	}
 
 	// get mutated performance tuned
-	clusterVersion, err := r.getClusterVersion()
-	if err != nil {
-		return nil, err
-	}
-	performanceTuned, err := tuned.NewNodePerformance(r.AssetsDir, profile, clusterVersion)
-	if err != nil {
-		return nil, err
-	}
-
-	if err := controllerutil.SetControllerReference(profile, performanceTuned, r.Scheme); err != nil {
-		return nil, err
-	}
-	performanceTunedMutated, err := r.getMutatedTuned(performanceTuned)
+	performanceTunedMutated, err := r.getMutatedTuned(components.Tuned)
 	if err != nil {
 		return nil, err
 	}
 
 	// get mutated RuntimeClass
-	runtimeClass := runtimeclass.New(profile, machineconfig.HighPerformanceRuntime)
-	if err := controllerutil.SetControllerReference(profile, runtimeClass, r.Scheme); err != nil {
-		return nil, err
-	}
-	runtimeClassMutated, err := r.getMutatedRuntimeClass(runtimeClass)
+	runtimeClassMutated, err := r.getMutatedRuntimeClass(components.RuntimeClass)
 	if err != nil {
 		return nil, err
 	}
@@ -478,11 +425,11 @@ func (r *PerformanceProfileReconciler) deleteComponents(profile *performancev2.P
 		return err
 	}
 
-	if err := r.deleteMachineConfig(name); err != nil {
+	if err := r.deleteRuntimeClass(name); err != nil {
 		return err
 	}
 
-	if err := r.deleteRuntimeClass(name); err != nil {
+	if err := r.deleteMachineConfig(machineconfig.GetMachineConfigName(profile)); err != nil {
 		return err
 	}
 
@@ -492,19 +439,24 @@ func (r *PerformanceProfileReconciler) deleteComponents(profile *performancev2.P
 
 func (r *PerformanceProfileReconciler) isComponentsExist(profile *performancev2.PerformanceProfile) bool {
 	tunedName := components.GetComponentName(profile.Name, components.ProfileNamePerformance)
-	if _, err := r.getTuned(tunedName, components.NamespaceNodeTuningOperator); !errors.IsNotFound(err) {
+	if _, err := r.getTuned(tunedName, components.NamespaceNodeTuningOperator); !k8serros.IsNotFound(err) {
 		klog.Infof("Tuned %q custom resource is still exists under the namespace %q", tunedName, components.NamespaceNodeTuningOperator)
 		return true
 	}
 
 	name := components.GetComponentName(profile.Name, components.ComponentNamePrefix)
-	if _, err := r.getKubeletConfig(name); !errors.IsNotFound(err) {
-		klog.Infof("Kubelet Config %q custom resource is still exists under the cluster", name)
+	if _, err := r.getKubeletConfig(name); !k8serros.IsNotFound(err) {
+		klog.Infof("Kubelet Config %q exists under the cluster", name)
 		return true
 	}
 
-	if _, err := r.getMachineConfig(name); !errors.IsNotFound(err) {
-		klog.Infof("Machine Config %q custom resource is still exists under the cluster", name)
+	if _, err := r.getRuntimeClass(name); !k8serros.IsNotFound(err) {
+		klog.Infof("Runtime class %q exists under the cluster", name)
+		return true
+	}
+
+	if _, err := r.getMachineConfig(machineconfig.GetMachineConfigName(profile)); !k8serros.IsNotFound(err) {
+		klog.Infof("Machine Config %q exists under the cluster", name)
 		return true
 	}
 
@@ -538,32 +490,82 @@ func namespacedName(obj metav1.Object) types.NamespacedName {
 	}
 }
 
-func hasMatchingLabels(performanceprofile *performancev2.PerformanceProfile, mcp *mcov1.MachineConfigPool) bool {
+func (r *PerformanceProfileReconciler) getMachineConfigPoolByProfile(profile *performancev2.PerformanceProfile) (*mcov1.MachineConfigPool, error) {
+	nodeSelector := labels.Set(profile.Spec.NodeSelector)
 
-	selector, err := metav1.LabelSelectorAsSelector(mcp.Spec.MachineConfigSelector)
+	mcpList := &mcov1.MachineConfigPoolList{}
+	if err := r.Client.List(context.TODO(), mcpList); err != nil {
+		return nil, err
+	}
+
+	filteredMCPList := filterMCPDuplications(mcpList.Items)
+
+	var profileMCPs []*mcov1.MachineConfigPool
+	for i := range filteredMCPList {
+		mcp := &mcpList.Items[i]
+
+		if mcp.Spec.NodeSelector == nil {
+			continue
+		}
+
+		mcpNodeSelector, err := metav1.LabelSelectorAsSelector(mcp.Spec.NodeSelector)
+		if err != nil {
+			return nil, err
+		}
+
+		if mcpNodeSelector.Matches(nodeSelector) {
+			profileMCPs = append(profileMCPs, mcp)
+		}
+	}
+
+	if len(profileMCPs) == 0 {
+		return nil, fmt.Errorf("failed to find MCP with the node selector that matches labels %q", nodeSelector.String())
+	}
+
+	if len(profileMCPs) > 1 {
+		return nil, fmt.Errorf("more than one MCP found that matches performance profile node selector %q", nodeSelector.String())
+	}
+
+	return profileMCPs[0], nil
+}
+
+func filterMCPDuplications(mcps []mcov1.MachineConfigPool) []mcov1.MachineConfigPool {
+	var filtered []mcov1.MachineConfigPool
+	items := map[string]mcov1.MachineConfigPool{}
+	for _, mcp := range mcps {
+		if _, exists := items[mcp.Name]; !exists {
+			items[mcp.Name] = mcp
+			filtered = append(filtered, mcp)
+		}
+	}
+
+	return filtered
+}
+
+func validateProfileMachineConfigPool(profile *performancev2.PerformanceProfile, profileMCP *mcov1.MachineConfigPool) error {
+	if profileMCP.Spec.MachineConfigSelector.Size() == 0 {
+		return fmt.Errorf("the MachineConfigPool %q machineConfigSelector is nil", profileMCP.Name)
+	}
+
+	if len(profileMCP.Labels) == 0 {
+		return fmt.Errorf("the MachineConfigPool %q does not have any labels that can be used to bind it together with KubeletConfing", profileMCP.Name)
+	}
+
+	// we can not guarantee that our generated label for the machine config selector will be the right one
+	// but at least we can validate that the MCP will consume our machine config
+	machineConfigLabels := profileutil.GetMachineConfigLabel(profile)
+	mcpMachineConfigSelector, err := metav1.LabelSelectorAsSelector(profileMCP.Spec.MachineConfigSelector)
 	if err != nil {
-		return false
-	}
-	// If a deployment with a nil or empty selector creeps in, it should match nothing, not everything.
-	if selector.Empty() {
-		return false
+		return err
 	}
 
-	if !selector.Matches(labels.Set(profileutil.GetMachineConfigPoolSelector(performanceprofile))) {
-		return false
-	}
-	return true
-}
+	if !mcpMachineConfigSelector.Matches(labels.Set(machineConfigLabels)) {
+		if len(profile.Spec.MachineConfigLabel) > 0 {
+			return fmt.Errorf("the machine config labels %v provided via profile.spec.machineConfigLabel do not match the MachineConfigPool %q machineConfigSelector %q", machineConfigLabels, profileMCP.Name, mcpMachineConfigSelector.String())
+		}
 
-func (r *PerformanceProfileReconciler) getClusterVersion() (string, error) {
-	clusterVersion := ""
-	cv := &v1.ClusterVersion{}
-	key := types.NamespacedName{
-		Name: "version",
+		return fmt.Errorf("the machine config labels %v generated from the profile.spec.nodeSelector %v do not match the MachineConfigPool %q machineConfigSelector %q", machineConfigLabels, profile.Spec.NodeSelector, profileMCP.Name, mcpMachineConfigSelector.String())
 	}
-	if err := r.Get(context.TODO(), key, cv); err != nil {
-		return clusterVersion, err
-	}
-	clusterVersion = cv.Status.Desired.Version
-	return clusterVersion, nil
+
+	return nil
 }
